@@ -47,8 +47,8 @@ async def async_setup_platform(
 ) -> None:
     """Set up Aladdin Connect devices yaml depreciated."""
     _LOGGER.warning(
-        "Configuring Aladdin Connect through yaml is deprecated"
-        "Please remove it from your configuration as it has already been imported to a config entry"
+        "Configuring Aladdin Connect through yaml is deprecated. Please remove it from"
+        " your configuration as it has already been imported to a config entry"
     )
     await hass.async_create_task(
         hass.config_entries.flow.async_init(
@@ -111,7 +111,7 @@ class AladdinDevice(CoverEntity):
             """Schedule a state update."""
             self.async_write_ha_state()
 
-        self._acc.register_callback(update_callback, self._serial)
+        self._acc.register_callback(update_callback, self._serial, self._number)
         await self._acc.get_doors(self._serial)
 
     async def async_will_remove_from_hass(self) -> None:
