@@ -13,9 +13,9 @@ from homeassistant import config_entries, data_entry_flow
 from homeassistant.auth.permissions.const import CAT_CONFIG_ENTRIES, POLICY_EDIT
 from homeassistant.components import websocket_api
 from homeassistant.components.http import HomeAssistantView
-from homeassistant.components.websocket_api.connection import ActiveConnection
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.exceptions import DependencyError, Unauthorized
+import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.data_entry_flow import (
     FlowManagerIndexView,
     FlowManagerResourceView,
@@ -65,7 +65,7 @@ class ConfigManagerEntryIndexView(HomeAssistantView):
             domain = request.query["domain"]
         type_filter = None
         if "type" in request.query:
-            type_filter = request.query["type"]
+            type_filter = [request.query["type"]]
         return self.json(await async_matching_config_entries(hass, type_filter, domain))
 
 
@@ -243,7 +243,11 @@ class OptionManagerFlowResourceView(FlowManagerResourceView):
 
 @websocket_api.require_admin
 @websocket_api.websocket_command({"type": "config_entries/flow/progress"})
-def config_entries_progress(hass, connection, msg):
+def config_entries_progress(
+    hass: HomeAssistant,
+    connection: websocket_api.ActiveConnection,
+    msg: dict[str, Any],
+) -> None:
     """List flows that are in progress but not started by a user.
 
     Example of a non-user initiated flow is a discovered Hue hub that
@@ -291,7 +295,11 @@ def get_entry(
     }
 )
 @websocket_api.async_response
-async def config_entry_update(hass, connection, msg):
+async def config_entry_update(
+    hass: HomeAssistant,
+    connection: websocket_api.ActiveConnection,
+    msg: dict[str, Any],
+) -> None:
     """Update config entry."""
     changes = dict(msg)
     changes.pop("id")
@@ -311,9 +319,10 @@ async def config_entry_update(hass, connection, msg):
         "require_restart": False,
     }
 
+    initial_state = entry.state
     if (
         old_disable_polling != entry.pref_disable_polling
-        and entry.state is config_entries.ConfigEntryState.LOADED
+        and initial_state is config_entries.ConfigEntryState.LOADED
     ):
         if not await hass.config_entries.async_reload(entry.entry_id):
             result["require_restart"] = (
@@ -334,14 +343,18 @@ async def config_entry_update(hass, connection, msg):
     }
 )
 @websocket_api.async_response
-async def config_entry_disable(hass, connection, msg):
+async def config_entry_disable(
+    hass: HomeAssistant,
+    connection: websocket_api.ActiveConnection,
+    msg: dict[str, Any],
+) -> None:
     """Disable config entry."""
     if (disabled_by := msg["disabled_by"]) is not None:
         disabled_by = config_entries.ConfigEntryDisabler(disabled_by)
 
-    result = False
+    success = False
     try:
-        result = await hass.config_entries.async_set_disabled_by(
+        success = await hass.config_entries.async_set_disabled_by(
             msg["entry_id"], disabled_by
         )
     except config_entries.OperationNotAllowed:
@@ -351,7 +364,7 @@ async def config_entry_disable(hass, connection, msg):
         send_entry_not_found(connection, msg["id"])
         return
 
-    result = {"require_restart": not result}
+    result = {"require_restart": not success}
 
     connection.send_result(msg["id"], result)
 
@@ -361,7 +374,11 @@ async def config_entry_disable(hass, connection, msg):
     {"type": "config_entries/ignore_flow", "flow_id": str, "title": str}
 )
 @websocket_api.async_response
-async def ignore_config_flow(hass, connection, msg):
+async def ignore_config_flow(
+    hass: HomeAssistant,
+    connection: websocket_api.ActiveConnection,
+    msg: dict[str, Any],
+) -> None:
     """Ignore a config flow."""
     flow = next(
         (
@@ -393,13 +410,15 @@ async def ignore_config_flow(hass, connection, msg):
 @websocket_api.websocket_command(
     {
         vol.Required("type"): "config_entries/get",
-        vol.Optional("type_filter"): str,
+        vol.Optional("type_filter"): vol.All(cv.ensure_list, [str]),
         vol.Optional("domain"): str,
     }
 )
 @websocket_api.async_response
 async def config_entries_get(
-    hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]
+    hass: HomeAssistant,
+    connection: websocket_api.ActiveConnection,
+    msg: dict[str, Any],
 ) -> None:
     """Return matching config entries by type and/or domain."""
     connection.send_result(
@@ -413,12 +432,14 @@ async def config_entries_get(
 @websocket_api.websocket_command(
     {
         vol.Required("type"): "config_entries/subscribe",
-        vol.Optional("type_filter"): str,
+        vol.Optional("type_filter"): vol.All(cv.ensure_list, [str]),
     }
 )
 @websocket_api.async_response
 async def config_entries_subscribe(
-    hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]
+    hass: HomeAssistant,
+    connection: websocket_api.ActiveConnection,
+    msg: dict[str, Any],
 ) -> None:
     """Subscribe to config entry updates."""
     type_filter = msg.get("type_filter")
@@ -429,7 +450,7 @@ async def config_entries_subscribe(
         """Forward config entry state events to websocket."""
         if type_filter:
             integration = await async_get_integration(hass, entry.domain)
-            if integration.integration_type != type_filter:
+            if integration.integration_type not in type_filter:
                 return
 
         connection.send_message(
@@ -459,7 +480,7 @@ async def config_entries_subscribe(
 
 
 async def async_matching_config_entries(
-    hass: HomeAssistant, type_filter: str | None, domain: str | None
+    hass: HomeAssistant, type_filter: list[str] | None, domain: str | None
 ) -> list[dict[str, Any]]:
     """Return matching config entries by type and/or domain."""
     kwargs = {}
@@ -467,7 +488,7 @@ async def async_matching_config_entries(
         kwargs["domain"] = domain
     entries = hass.config_entries.async_entries(**kwargs)
 
-    if type_filter is None:
+    if not type_filter:
         return [entry_json(entry) for entry in entries]
 
     integrations = {}
@@ -483,13 +504,17 @@ async def async_matching_config_entries(
         elif not isinstance(integration_or_exc, IntegrationNotFound):
             raise integration_or_exc
 
+    # Filter out entries that don't match the type filter
+    # when only helpers are requested, also filter out entries
+    # from unknown integrations. This prevent them from showing
+    # up in the helpers UI.
     entries = [
         entry
         for entry in entries
-        if (type_filter != "helper" and entry.domain not in integrations)
+        if (type_filter != ["helper"] and entry.domain not in integrations)
         or (
             entry.domain in integrations
-            and integrations[entry.domain].integration_type == type_filter
+            and integrations[entry.domain].integration_type in type_filter
         )
     ]
 
