@@ -2,11 +2,28 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
+from dataclasses import dataclass
+from typing import Any
 
 from homeassistant.core import Context
 from homeassistant.helpers import intent
 
 
+@dataclass
+class ConversationResult:
+    """Result of async_process."""
+
+    response: intent.IntentResponse
+    conversation_id: str | None = None
+
+    def as_dict(self) -> dict[str, Any]:
+        """Return result as a dict."""
+        return {
+            "response": self.response.as_dict(),
+            "conversation_id": self.conversation_id,
+        }
+
+
 class AbstractConversationAgent(ABC):
     """Abstract conversation agent."""
 
@@ -25,6 +42,10 @@ class AbstractConversationAgent(ABC):
 
     @abstractmethod
     async def async_process(
-        self, text: str, context: Context, conversation_id: str | None = None
-    ) -> intent.IntentResponse | None:
+        self,
+        text: str,
+        context: Context,
+        conversation_id: str | None = None,
+        language: str | None = None,
+    ) -> ConversationResult | None:
         """Process a sentence."""
