@@ -57,7 +57,8 @@ class FreeboxSwitch(SwitchEntity):
             await self._router.wifi.set_global_config({"enabled": enabled})
         except InsufficientPermissionsError:
             _LOGGER.warning(
-                "Home Assistant does not have permissions to modify the Freebox settings. Please refer to documentation"
+                "Home Assistant does not have permissions to modify the Freebox"
+                " settings. Please refer to documentation"
             )
 
     async def async_turn_on(self, **kwargs: Any) -> None:
