@@ -136,7 +136,7 @@ class HostInfo(TypedDict):
     status: bool
 
 
-class FritzBoxTools(update_coordinator.DataUpdateCoordinator):
+class FritzBoxTools(update_coordinator.DataUpdateCoordinator[None]):
     """FritzBoxTools class."""
 
     def __init__(
@@ -328,7 +328,10 @@ class FritzBoxTools(update_coordinator.DataUpdateCoordinator):
             ).get("NewDisallow")
         except FRITZ_EXCEPTIONS as ex:
             _LOGGER.debug(
-                "could not get WAN access rule for client device with IP '%s', error: %s",
+                (
+                    "could not get WAN access rule for client device with IP '%s',"
+                    " error: %s"
+                ),
                 ip_address,
                 ex,
             )
@@ -574,21 +577,24 @@ class FritzBoxTools(update_coordinator.DataUpdateCoordinator):
         try:
             if service_call.service == SERVICE_REBOOT:
                 _LOGGER.warning(
-                    'Service "fritz.reboot" is deprecated, please use the corresponding button entity instead'
+                    'Service "fritz.reboot" is deprecated, please use the corresponding'
+                    " button entity instead"
                 )
                 await self.async_trigger_reboot()
                 return
 
             if service_call.service == SERVICE_RECONNECT:
                 _LOGGER.warning(
-                    'Service "fritz.reconnect" is deprecated, please use the corresponding button entity instead'
+                    'Service "fritz.reconnect" is deprecated, please use the'
+                    " corresponding button entity instead"
                 )
                 await self.async_trigger_reconnect()
                 return
 
             if service_call.service == SERVICE_CLEANUP:
                 _LOGGER.warning(
-                    'Service "fritz.cleanup" is deprecated, please use the corresponding button entity instead'
+                    'Service "fritz.cleanup" is deprecated, please use the'
+                    " corresponding button entity instead"
                 )
                 await self.async_trigger_cleanup(config_entry)
                 return
@@ -634,7 +640,10 @@ class AvmWrapper(FritzBoxTools):
             return result
         except FritzSecurityError:
             _LOGGER.error(
-                "Authorization Error: Please check the provided credentials and verify that you can log into the web interface",
+                (
+                    "Authorization Error: Please check the provided credentials and"
+                    " verify that you can log into the web interface"
+                ),
                 exc_info=True,
             )
         except FRITZ_EXCEPTIONS:
@@ -646,7 +655,10 @@ class AvmWrapper(FritzBoxTools):
             )
         except FritzConnectionException:
             _LOGGER.error(
-                "Connection Error: Please check the device is properly configured for remote login",
+                (
+                    "Connection Error: Please check the device is properly configured"
+                    " for remote login"
+                ),
                 exc_info=True,
             )
         return {}
@@ -663,6 +675,17 @@ class AvmWrapper(FritzBoxTools):
             partial(self.get_wan_link_properties)
         )
 
+    async def async_ipv6_active(self) -> bool:
+        """Check ip an ipv6 is active on the WAn interface."""
+
+        def wrap_external_ipv6() -> str:
+            return str(self.fritz_status.external_ipv6)
+
+        if not self.device_is_router:
+            return False
+
+        return bool(await self.hass.async_add_executor_job(wrap_external_ipv6))
+
     async def async_get_connection_info(self) -> ConnectionInfo:
         """Return ConnectionInfo data."""
 
@@ -671,6 +694,7 @@ class AvmWrapper(FritzBoxTools):
             connection=link_properties.get("NewWANAccessType", "").lower(),
             mesh_role=self.mesh_role,
             wan_enabled=self.device_is_router,
+            ipv6_active=await self.async_ipv6_active(),
         )
         _LOGGER.debug(
             "ConnectionInfo for FritzBox %s: %s",
@@ -1011,3 +1035,4 @@ class ConnectionInfo:
     connection: str
     mesh_role: MeshRoles
     wan_enabled: bool
+    ipv6_active: bool
