@@ -4,13 +4,8 @@ from __future__ import annotations
 from dataclasses import asdict
 import logging
 
-from homeassistant.components.sensor import (
-    ATTR_STATE_CLASS,
-    RestoreSensor,
-    SensorDeviceClass,
-)
+from homeassistant.components.sensor import RestoreSensor, SensorDeviceClass
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import ATTR_DEVICE_CLASS, ATTR_UNIT_OF_MEASUREMENT
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity import DeviceInfo
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -27,8 +22,6 @@ async def async_setup_entry(
     hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback
 ) -> None:
     """Set up the sensor platform."""
-    _LOGGER.info("The Landis+Gyr Heat Meter sensor platform is being set up!")
-
     unique_id = entry.entry_id
     coordinator = hass.data[DOMAIN][entry.entry_id]
 
@@ -44,7 +37,7 @@ async def async_setup_entry(
     sensors = []
 
     for description in HEAT_METER_SENSOR_TYPES:
-        sensors.append(HeatMeterSensor(coordinator, unique_id, description, device))
+        sensors.append(HeatMeterSensor(coordinator, description, device))
 
     async_add_entities(sensors)
 
@@ -52,24 +45,16 @@ async def async_setup_entry(
 class HeatMeterSensor(CoordinatorEntity, RestoreSensor):
     """Representation of a Sensor."""
 
-    def __init__(self, coordinator, unique_id, description, device):
+    def __init__(self, coordinator, description, device):
         """Set up the sensor with the initial values."""
         super().__init__(coordinator)
         self.key = description.key
-        self._attr_unique_id = f"{DOMAIN}_{unique_id}_{description.key}"
-        self._attr_name = "Heat Meter " + description.name
-        if hasattr(description, "icon"):
-            self._attr_icon = description.icon
-        if hasattr(description, "entity_category"):
-            self._attr_entity_category = description.entity_category
-        if hasattr(description, ATTR_STATE_CLASS):
-            self._attr_state_class = description.state_class
-        if hasattr(description, ATTR_DEVICE_CLASS):
-            self._attr_device_class = description.device_class
-        if hasattr(description, ATTR_UNIT_OF_MEASUREMENT):
-            self._attr_native_unit_of_measurement = (
-                description.native_unit_of_measurement
-            )
+        self._attr_unique_id = (
+            f"{coordinator.config_entry.data['device_number']}_{description.key}"
+        )
+        self._attr_name = f"Heat Meter {description.name}"
+        self.entity_description = description
+
         self._attr_device_info = device
         self._attr_should_poll = bool(self.key in ("heat_usage", "heat_previous_year"))
 
