@@ -141,6 +141,11 @@ class MelCloudDevice:
             name=self.name,
         )
 
+    @property
+    def daily_energy_consumed(self) -> float | None:
+        """Return energy consumed during the current day in kWh."""
+        return self.device.daily_energy_consumed
+
 
 async def mel_devices_setup(hass, token) -> dict[str, list[MelCloudDevice]]:
     """Query connected devices from MELCloud."""
