@@ -1,6 +1,9 @@
 """Support for MQTT JSON lights."""
+from __future__ import annotations
+
 from contextlib import suppress
 import logging
+from typing import Any, cast
 
 import voluptuous as vol
 
@@ -29,6 +32,7 @@ from homeassistant.components.light import (
     filter_supported_color_modes,
     valid_supported_color_modes,
 )
+from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
     CONF_BRIGHTNESS,
     CONF_COLOR_TEMP,
@@ -40,11 +44,12 @@ from homeassistant.const import (
     CONF_XY,
     STATE_ON,
 )
-from homeassistant.core import callback
+from homeassistant.core import HomeAssistant, callback
 import homeassistant.helpers.config_validation as cv
+from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.json import json_dumps, json_loads
 from homeassistant.helpers.restore_state import RestoreEntity
-from homeassistant.helpers.typing import ConfigType
+from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 import homeassistant.util.color as color_util
 
 from .. import subscription
@@ -58,6 +63,7 @@ from ..const import (
 )
 from ..debug_info import log_messages
 from ..mixins import MQTT_ENTITY_COMMON_SCHEMA, MqttEntity
+from ..models import ReceiveMessage
 from ..util import get_mqtt_data, valid_subscribe_topic
 from .schema import MQTT_LIGHT_SCHEMA_SCHEMA
 from .schema_basic import (
@@ -98,7 +104,7 @@ CONF_MIN_MIREDS = "min_mireds"
 CONF_WHITE_VALUE = "white_value"
 
 
-def valid_color_configuration(config):
+def valid_color_configuration(config: ConfigType) -> ConfigType:
     """Test color_mode is not combined with deprecated config."""
     deprecated = {CONF_COLOR_TEMP, CONF_HS, CONF_RGB, CONF_XY}
     if config[CONF_COLOR_MODE] and any(config.get(key) for key in deprecated):
@@ -152,7 +158,7 @@ _PLATFORM_SCHEMA_BASE = (
     .extend(MQTT_LIGHT_SCHEMA_SCHEMA.schema)
 )
 
-# Configuring MQTT Lights under the light platform key is deprecated in HA Core 2022.6
+# Configuring MQTT Lights under the light platform key was deprecated in HA Core 2022.6
 PLATFORM_SCHEMA_JSON = vol.All(
     cv.PLATFORM_SCHEMA.extend(_PLATFORM_SCHEMA_BASE.schema),
     valid_color_configuration,
@@ -174,8 +180,12 @@ PLATFORM_SCHEMA_MODERN_JSON = vol.All(
 
 
 async def async_setup_entity_json(
-    hass, config: ConfigType, async_add_entities, config_entry, discovery_data
-):
+    hass: HomeAssistant,
+    config: ConfigType,
+    async_add_entities: AddEntitiesCallback,
+    config_entry: ConfigEntry,
+    discovery_data: DiscoveryInfoType | None,
+) -> None:
     """Set up a MQTT JSON Light."""
     async_add_entities([MqttLightJson(hass, config, config_entry, discovery_data)])
 
@@ -186,38 +196,36 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
     _entity_id_format = ENTITY_ID_FORMAT
     _attributes_extra_blocked = MQTT_LIGHT_ATTRIBUTES_BLOCKED
 
-    def __init__(self, hass, config, config_entry, discovery_data):
+    _flash_times: dict[str, int | None]
+    _topic: dict[str, str | None]
+    _optimistic: bool
+
+    def __init__(
+        self,
+        hass: HomeAssistant,
+        config: ConfigType,
+        config_entry: ConfigEntry,
+        discovery_data: DiscoveryInfoType | None,
+    ) -> None:
         """Initialize MQTT JSON light."""
-        self._state = None
-        self._supported_features = 0
-
-        self._topic = None
-        self._optimistic = False
-        self._brightness = None
-        self._color_mode = None
-        self._color_temp = None
-        self._effect = None
-        self._fixed_color_mode = None
-        self._flash_times = None
-        self._hs = None
-        self._rgb = None
-        self._rgbw = None
-        self._rgbww = None
-        self._xy = None
-
+        self._fixed_color_mode: ColorMode | str | None = None
         MqttEntity.__init__(self, hass, config, config_entry, discovery_data)
 
     @staticmethod
-    def config_schema():
+    def config_schema() -> vol.Schema:
         """Return the config schema."""
         return DISCOVERY_SCHEMA_JSON
 
-    def _setup_from_config(self, config):
+    def _setup_from_config(self, config: ConfigType) -> None:
         """(Re)Setup the entity."""
+        self._attr_max_mireds = config.get(CONF_MAX_MIREDS, super().max_mireds)
+        self._attr_min_mireds = config.get(CONF_MIN_MIREDS, super().min_mireds)
+        self._attr_effect_list = config.get(CONF_EFFECT_LIST)
+
         self._topic = {
             key: config.get(key) for key in (CONF_STATE_TOPIC, CONF_COMMAND_TOPIC)
         }
-        optimistic = config[CONF_OPTIMISTIC]
+        optimistic: bool = config[CONF_OPTIMISTIC]
         self._optimistic = optimistic or self._topic[CONF_STATE_TOPIC] is None
 
         self._flash_times = {
@@ -225,10 +233,12 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
             for key in (CONF_FLASH_TIME_SHORT, CONF_FLASH_TIME_LONG)
         }
 
-        self._supported_features = (
+        self._attr_supported_features = (
             LightEntityFeature.TRANSITION | LightEntityFeature.FLASH
         )
-        self._supported_features |= config[CONF_EFFECT] and LightEntityFeature.EFFECT
+        self._attr_supported_features |= (
+            config[CONF_EFFECT] and LightEntityFeature.EFFECT
+        )
         if not self._config[CONF_COLOR_MODE]:
             color_modes = {ColorMode.ONOFF}
             if config[CONF_BRIGHTNESS]:
@@ -237,22 +247,22 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                 color_modes.add(ColorMode.COLOR_TEMP)
             if config[CONF_HS] or config[CONF_RGB] or config[CONF_XY]:
                 color_modes.add(ColorMode.HS)
-            self._supported_color_modes = filter_supported_color_modes(color_modes)
-            if len(self._supported_color_modes) == 1:
-                self._fixed_color_mode = next(iter(self._supported_color_modes))
+            self._attr_supported_color_modes = filter_supported_color_modes(color_modes)
+            if self.supported_color_modes and len(self.supported_color_modes) == 1:
+                self._fixed_color_mode = next(iter(self.supported_color_modes))
         else:
-            self._supported_color_modes = self._config[CONF_SUPPORTED_COLOR_MODES]
-            if len(self._supported_color_modes) == 1:
-                self._color_mode = next(iter(self._supported_color_modes))
+            self._attr_supported_color_modes = self._config[CONF_SUPPORTED_COLOR_MODES]
+            if self.supported_color_modes and len(self.supported_color_modes) == 1:
+                self._attr_color_mode = next(iter(self.supported_color_modes))
 
-    def _update_color(self, values):
+    def _update_color(self, values: dict[str, Any]) -> None:
         if not self._config[CONF_COLOR_MODE]:
             # Deprecated color handling
             try:
                 red = int(values["color"]["r"])
                 green = int(values["color"]["g"])
                 blue = int(values["color"]["b"])
-                self._hs = color_util.color_RGB_to_hs(red, green, blue)
+                self._attr_hs_color = color_util.color_RGB_to_hs(red, green, blue)
             except KeyError:
                 pass
             except ValueError:
@@ -264,7 +274,7 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
             try:
                 x_color = float(values["color"]["x"])
                 y_color = float(values["color"]["y"])
-                self._hs = color_util.color_xy_to_hs(x_color, y_color)
+                self._attr_hs_color = color_util.color_xy_to_hs(x_color, y_color)
             except KeyError:
                 pass
             except ValueError:
@@ -276,7 +286,7 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
             try:
                 hue = float(values["color"]["h"])
                 saturation = float(values["color"]["s"])
-                self._hs = (hue, saturation)
+                self._attr_hs_color = (hue, saturation)
             except KeyError:
                 pass
             except ValueError:
@@ -285,7 +295,7 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                 )
                 return
         else:
-            color_mode = values["color_mode"]
+            color_mode: str = values["color_mode"]
             if not self._supports_color_mode(color_mode):
                 _LOGGER.warning(
                     "Invalid color mode received for entity %s", self.entity_id
@@ -293,80 +303,80 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                 return
             try:
                 if color_mode == ColorMode.COLOR_TEMP:
-                    self._color_temp = int(values["color_temp"])
-                    self._color_mode = ColorMode.COLOR_TEMP
+                    self._attr_color_temp = int(values["color_temp"])
+                    self._attr_color_mode = ColorMode.COLOR_TEMP
                 elif color_mode == ColorMode.HS:
                     hue = float(values["color"]["h"])
                     saturation = float(values["color"]["s"])
-                    self._color_mode = ColorMode.HS
-                    self._hs = (hue, saturation)
+                    self._attr_color_mode = ColorMode.HS
+                    self._attr_hs_color = (hue, saturation)
                 elif color_mode == ColorMode.RGB:
                     r = int(values["color"]["r"])  # pylint: disable=invalid-name
                     g = int(values["color"]["g"])  # pylint: disable=invalid-name
                     b = int(values["color"]["b"])  # pylint: disable=invalid-name
-                    self._color_mode = ColorMode.RGB
-                    self._rgb = (r, g, b)
+                    self._attr_color_mode = ColorMode.RGB
+                    self._attr_rgb_color = (r, g, b)
                 elif color_mode == ColorMode.RGBW:
                     r = int(values["color"]["r"])  # pylint: disable=invalid-name
                     g = int(values["color"]["g"])  # pylint: disable=invalid-name
                     b = int(values["color"]["b"])  # pylint: disable=invalid-name
                     w = int(values["color"]["w"])  # pylint: disable=invalid-name
-                    self._color_mode = ColorMode.RGBW
-                    self._rgbw = (r, g, b, w)
+                    self._attr_color_mode = ColorMode.RGBW
+                    self._attr_rgbw_color = (r, g, b, w)
                 elif color_mode == ColorMode.RGBWW:
                     r = int(values["color"]["r"])  # pylint: disable=invalid-name
                     g = int(values["color"]["g"])  # pylint: disable=invalid-name
                     b = int(values["color"]["b"])  # pylint: disable=invalid-name
                     c = int(values["color"]["c"])  # pylint: disable=invalid-name
                     w = int(values["color"]["w"])  # pylint: disable=invalid-name
-                    self._color_mode = ColorMode.RGBWW
-                    self._rgbww = (r, g, b, c, w)
+                    self._attr_color_mode = ColorMode.RGBWW
+                    self._attr_rgbww_color = (r, g, b, c, w)
                 elif color_mode == ColorMode.WHITE:
-                    self._color_mode = ColorMode.WHITE
+                    self._attr_color_mode = ColorMode.WHITE
                 elif color_mode == ColorMode.XY:
                     x = float(values["color"]["x"])  # pylint: disable=invalid-name
                     y = float(values["color"]["y"])  # pylint: disable=invalid-name
-                    self._color_mode = ColorMode.XY
-                    self._xy = (x, y)
+                    self._attr_color_mode = ColorMode.XY
+                    self._attr_xy_color = (x, y)
             except (KeyError, ValueError):
                 _LOGGER.warning(
                     "Invalid or incomplete color value received for entity %s",
                     self.entity_id,
                 )
 
-    def _prepare_subscribe_topics(self):
+    def _prepare_subscribe_topics(self) -> None:
         """(Re)Subscribe to topics."""
 
         @callback
         @log_messages(self.hass, self.entity_id)
-        def state_received(msg):
+        def state_received(msg: ReceiveMessage) -> None:
             """Handle new MQTT messages."""
-            values = json_loads(msg.payload)
+            values: dict[str, Any] = json_loads(msg.payload)
 
             if values["state"] == "ON":
-                self._state = True
+                self._attr_is_on = True
             elif values["state"] == "OFF":
-                self._state = False
+                self._attr_is_on = False
             elif values["state"] is None:
-                self._state = None
+                self._attr_is_on = None
 
             if (
                 not self._config[CONF_COLOR_MODE]
-                and color_supported(self._supported_color_modes)
+                and color_supported(self.supported_color_modes)
                 and "color" in values
             ):
                 # Deprecated color handling
                 if values["color"] is None:
-                    self._hs = None
+                    self._attr_hs_color = None
                 else:
                     self._update_color(values)
 
             if self._config[CONF_COLOR_MODE] and "color_mode" in values:
                 self._update_color(values)
 
-            if brightness_supported(self._supported_color_modes):
+            if brightness_supported(self.supported_color_modes):
                 try:
-                    self._brightness = int(
+                    self._attr_brightness = int(
                         values["brightness"]
                         / float(self._config[CONF_BRIGHTNESS_SCALE])
                         * 255
@@ -380,15 +390,16 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                     )
 
             if (
-                ColorMode.COLOR_TEMP in self._supported_color_modes
+                self.supported_color_modes
+                and ColorMode.COLOR_TEMP in self.supported_color_modes
                 and not self._config[CONF_COLOR_MODE]
             ):
                 # Deprecated color handling
                 try:
                     if values["color_temp"] is None:
-                        self._color_temp = None
+                        self._attr_color_temp = None
                     else:
-                        self._color_temp = int(values["color_temp"])
+                        self._attr_color_temp = int(values["color_temp"])
                 except KeyError:
                     pass
                 except ValueError:
@@ -397,9 +408,9 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                         self.entity_id,
                     )
 
-            if self._supported_features and LightEntityFeature.EFFECT:
+            if self.supported_features and LightEntityFeature.EFFECT:
                 with suppress(KeyError):
-                    self._effect = values["effect"]
+                    self._attr_effect = values["effect"]
 
             get_mqtt_data(self.hass).state_write_requests.write_state_request(self)
 
@@ -417,147 +428,95 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                 },
             )
 
-    async def _subscribe_topics(self):
+    async def _subscribe_topics(self) -> None:
         """(Re)Subscribe to topics."""
         await subscription.async_subscribe_topics(self.hass, self._sub_state)
 
         last_state = await self.async_get_last_state()
         if self._optimistic and last_state:
-            self._state = last_state.state == STATE_ON
+            self._attr_is_on = last_state.state == STATE_ON
             last_attributes = last_state.attributes
-            self._brightness = last_attributes.get(ATTR_BRIGHTNESS, self._brightness)
-            self._color_mode = last_attributes.get(ATTR_COLOR_MODE, self._color_mode)
-            self._color_temp = last_attributes.get(ATTR_COLOR_TEMP, self._color_temp)
-            self._effect = last_attributes.get(ATTR_EFFECT, self._effect)
-            self._hs = last_attributes.get(ATTR_HS_COLOR, self._hs)
-            self._rgb = last_attributes.get(ATTR_RGB_COLOR, self._rgb)
-            self._rgbw = last_attributes.get(ATTR_RGBW_COLOR, self._rgbw)
-            self._rgbww = last_attributes.get(ATTR_RGBWW_COLOR, self._rgbww)
-            self._xy = last_attributes.get(ATTR_XY_COLOR, self._xy)
+            self._attr_brightness = last_attributes.get(
+                ATTR_BRIGHTNESS, self.brightness
+            )
+            self._attr_color_mode = last_attributes.get(
+                ATTR_COLOR_MODE, self.color_mode
+            )
+            self._attr_color_temp = last_attributes.get(
+                ATTR_COLOR_TEMP, self.color_temp
+            )
+            self._attr_effect = last_attributes.get(ATTR_EFFECT, self.effect)
+            self._attr_hs_color = last_attributes.get(ATTR_HS_COLOR, self.hs_color)
+            self._attr_rgb_color = last_attributes.get(ATTR_RGB_COLOR, self.rgb_color)
+            self._attr_rgbw_color = last_attributes.get(
+                ATTR_RGBW_COLOR, self.rgbw_color
+            )
+            self._attr_rgbww_color = last_attributes.get(
+                ATTR_RGBWW_COLOR, self.rgbww_color
+            )
+            self._attr_xy_color = last_attributes.get(ATTR_XY_COLOR, self.xy_color)
 
     @property
-    def brightness(self):
-        """Return the brightness of this light between 0..255."""
-        return self._brightness
-
-    @property
-    def color_temp(self):
-        """Return the color temperature in mired."""
-        return self._color_temp
-
-    @property
-    def min_mireds(self):
-        """Return the coldest color_temp that this light supports."""
-        return self._config.get(CONF_MIN_MIREDS, super().min_mireds)
-
-    @property
-    def max_mireds(self):
-        """Return the warmest color_temp that this light supports."""
-        return self._config.get(CONF_MAX_MIREDS, super().max_mireds)
-
-    @property
-    def effect(self):
-        """Return the current effect."""
-        return self._effect
-
-    @property
-    def effect_list(self):
-        """Return the list of supported effects."""
-        return self._config.get(CONF_EFFECT_LIST)
-
-    @property
-    def hs_color(self):
-        """Return the hs color value."""
-        return self._hs
-
-    @property
-    def rgb_color(self):
-        """Return the hs color value."""
-        return self._rgb
-
-    @property
-    def rgbw_color(self):
-        """Return the hs color value."""
-        return self._rgbw
-
-    @property
-    def rgbww_color(self):
-        """Return the hs color value."""
-        return self._rgbww
-
-    @property
-    def xy_color(self):
-        """Return the hs color value."""
-        return self._xy
-
-    @property
-    def is_on(self):
-        """Return true if device is on."""
-        return self._state
-
-    @property
-    def assumed_state(self):
+    def assumed_state(self) -> bool:
         """Return true if we do optimistic updates."""
         return self._optimistic
 
     @property
-    def color_mode(self):
+    def color_mode(self) -> ColorMode | str | None:
         """Return current color mode."""
         if self._config[CONF_COLOR_MODE]:
-            return self._color_mode
+            return self._attr_color_mode
         if self._fixed_color_mode:
             # Legacy light with support for a single color mode
             return self._fixed_color_mode
         # Legacy light with support for ct + hs, prioritize hs
-        if self._hs is not None:
+        if self.hs_color is not None:
             return ColorMode.HS
         return ColorMode.COLOR_TEMP
 
-    @property
-    def supported_color_modes(self):
-        """Flag supported color modes."""
-        return self._supported_color_modes
-
-    @property
-    def supported_features(self):
-        """Flag supported features."""
-        return self._supported_features
-
-    def _set_flash_and_transition(self, message, **kwargs):
+    def _set_flash_and_transition(self, message: dict[str, Any], **kwargs: Any) -> None:
         if ATTR_TRANSITION in kwargs:
             message["transition"] = kwargs[ATTR_TRANSITION]
 
         if ATTR_FLASH in kwargs:
-            flash = kwargs.get(ATTR_FLASH)
+            flash: str = kwargs[ATTR_FLASH]
 
             if flash == FLASH_LONG:
                 message["flash"] = self._flash_times[CONF_FLASH_TIME_LONG]
             elif flash == FLASH_SHORT:
                 message["flash"] = self._flash_times[CONF_FLASH_TIME_SHORT]
 
-    def _scale_rgbxx(self, rgbxx, kwargs):
+    def _scale_rgbxx(self, rgbxx: tuple[int, ...], kwargs: Any) -> tuple[int, ...]:
         # If there's a brightness topic set, we don't want to scale the
         # RGBxx values given using the brightness.
+        brightness: int
         if self._config[CONF_BRIGHTNESS]:
             brightness = 255
         else:
             brightness = kwargs.get(ATTR_BRIGHTNESS, 255)
         return tuple(round(i / 255 * brightness) for i in rgbxx)
 
-    def _supports_color_mode(self, color_mode):
+    def _supports_color_mode(self, color_mode: ColorMode | str) -> bool:
         """Return True if the light natively supports a color mode."""
         return (
-            self._config[CONF_COLOR_MODE] and color_mode in self.supported_color_modes
+            self._config[CONF_COLOR_MODE]
+            and self.supported_color_modes is not None
+            and color_mode in self.supported_color_modes
         )
 
-    async def async_turn_on(self, **kwargs):  # noqa: C901
+    async def async_turn_on(self, **kwargs: Any) -> None:  # noqa: C901
         """Turn the device on.
 
         This method is a coroutine.
         """
+        brightness: int
         should_update = False
-
-        message = {"state": "ON"}
+        hs_color: tuple[float, float]
+        message: dict[str, Any] = {"state": "ON"}
+        rgb: tuple[int, ...]
+        rgbw: tuple[int, ...]
+        rgbcw: tuple[int, ...]
+        xy_color: tuple[float, float]
 
         if ATTR_HS_COLOR in kwargs and (
             self._config[CONF_HS] or self._config[CONF_RGB] or self._config[CONF_XY]
@@ -587,54 +546,54 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                 message["color"]["s"] = hs_color[1]
 
             if self._optimistic:
-                self._color_temp = None
-                self._hs = kwargs[ATTR_HS_COLOR]
+                self._attr_color_temp = None
+                self._attr_hs_color = kwargs[ATTR_HS_COLOR]
                 should_update = True
 
         if ATTR_HS_COLOR in kwargs and self._supports_color_mode(ColorMode.HS):
             hs_color = kwargs[ATTR_HS_COLOR]
             message["color"] = {"h": hs_color[0], "s": hs_color[1]}
             if self._optimistic:
-                self._color_mode = ColorMode.HS
-                self._hs = hs_color
+                self._attr_color_mode = ColorMode.HS
+                self._attr_hs_color = hs_color
                 should_update = True
 
         if ATTR_RGB_COLOR in kwargs and self._supports_color_mode(ColorMode.RGB):
             rgb = self._scale_rgbxx(kwargs[ATTR_RGB_COLOR], kwargs)
             message["color"] = {"r": rgb[0], "g": rgb[1], "b": rgb[2]}
             if self._optimistic:
-                self._color_mode = ColorMode.RGB
-                self._rgb = rgb
+                self._attr_color_mode = ColorMode.RGB
+                self._attr_rgb_color = cast(tuple[int, int, int], rgb)
                 should_update = True
 
         if ATTR_RGBW_COLOR in kwargs and self._supports_color_mode(ColorMode.RGBW):
-            rgb = self._scale_rgbxx(kwargs[ATTR_RGBW_COLOR], kwargs)
-            message["color"] = {"r": rgb[0], "g": rgb[1], "b": rgb[2], "w": rgb[3]}
+            rgbw = self._scale_rgbxx(kwargs[ATTR_RGBW_COLOR], kwargs)
+            message["color"] = {"r": rgbw[0], "g": rgbw[1], "b": rgbw[2], "w": rgbw[3]}
             if self._optimistic:
-                self._color_mode = ColorMode.RGBW
-                self._rgbw = rgb
+                self._attr_color_mode = ColorMode.RGBW
+                self._attr_rgbw_color = cast(tuple[int, int, int, int], rgbw)
                 should_update = True
 
         if ATTR_RGBWW_COLOR in kwargs and self._supports_color_mode(ColorMode.RGBWW):
-            rgb = self._scale_rgbxx(kwargs[ATTR_RGBWW_COLOR], kwargs)
+            rgbcw = self._scale_rgbxx(kwargs[ATTR_RGBWW_COLOR], kwargs)
             message["color"] = {
-                "r": rgb[0],
-                "g": rgb[1],
-                "b": rgb[2],
-                "c": rgb[3],
-                "w": rgb[4],
+                "r": rgbcw[0],
+                "g": rgbcw[1],
+                "b": rgbcw[2],
+                "c": rgbcw[3],
+                "w": rgbcw[4],
             }
             if self._optimistic:
-                self._color_mode = ColorMode.RGBWW
-                self._rgbww = rgb
+                self._attr_color_mode = ColorMode.RGBWW
+                self._attr_rgbww_color = cast(tuple[int, int, int, int, int], rgbcw)
                 should_update = True
 
         if ATTR_XY_COLOR in kwargs and self._supports_color_mode(ColorMode.XY):
-            xy = kwargs[ATTR_XY_COLOR]  # pylint: disable=invalid-name
-            message["color"] = {"x": xy[0], "y": xy[1]}
+            xy_color = kwargs[ATTR_XY_COLOR]
+            message["color"] = {"x": xy_color[0], "y": xy_color[1]}
             if self._optimistic:
-                self._color_mode = ColorMode.XY
-                self._xy = xy
+                self._attr_color_mode = ColorMode.XY
+                self._attr_xy_color = xy_color
                 should_update = True
 
         self._set_flash_and_transition(message, **kwargs)
@@ -650,23 +609,23 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
             message["brightness"] = device_brightness
 
             if self._optimistic:
-                self._brightness = kwargs[ATTR_BRIGHTNESS]
+                self._attr_brightness = kwargs[ATTR_BRIGHTNESS]
                 should_update = True
 
         if ATTR_COLOR_TEMP in kwargs:
             message["color_temp"] = int(kwargs[ATTR_COLOR_TEMP])
 
             if self._optimistic:
-                self._color_mode = ColorMode.COLOR_TEMP
-                self._color_temp = kwargs[ATTR_COLOR_TEMP]
-                self._hs = None
+                self._attr_color_mode = ColorMode.COLOR_TEMP
+                self._attr_color_temp = kwargs[ATTR_COLOR_TEMP]
+                self._attr_hs_color = None
                 should_update = True
 
         if ATTR_EFFECT in kwargs:
             message["effect"] = kwargs[ATTR_EFFECT]
 
             if self._optimistic:
-                self._effect = kwargs[ATTR_EFFECT]
+                self._attr_effect = kwargs[ATTR_EFFECT]
                 should_update = True
 
         if ATTR_WHITE in kwargs and self._supports_color_mode(ColorMode.WHITE):
@@ -678,12 +637,12 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
             message["white"] = device_white_level
 
             if self._optimistic:
-                self._color_mode = ColorMode.WHITE
-                self._brightness = kwargs[ATTR_WHITE]
+                self._attr_color_mode = ColorMode.WHITE
+                self._attr_brightness = kwargs[ATTR_WHITE]
                 should_update = True
 
         await self.async_publish(
-            self._topic[CONF_COMMAND_TOPIC],
+            str(self._topic[CONF_COMMAND_TOPIC]),
             json_dumps(message),
             self._config[CONF_QOS],
             self._config[CONF_RETAIN],
@@ -692,23 +651,23 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
 
         if self._optimistic:
             # Optimistically assume that the light has changed state.
-            self._state = True
+            self._attr_is_on = True
             should_update = True
 
         if should_update:
             self.async_write_ha_state()
 
-    async def async_turn_off(self, **kwargs):
+    async def async_turn_off(self, **kwargs: Any) -> None:
         """Turn the device off.
 
         This method is a coroutine.
         """
-        message = {"state": "OFF"}
+        message: dict[str, Any] = {"state": "OFF"}
 
         self._set_flash_and_transition(message, **kwargs)
 
         await self.async_publish(
-            self._topic[CONF_COMMAND_TOPIC],
+            str(self._topic[CONF_COMMAND_TOPIC]),
             json_dumps(message),
             self._config[CONF_QOS],
             self._config[CONF_RETAIN],
@@ -717,5 +676,5 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
 
         if self._optimistic:
             # Optimistically assume that the light has changed state.
-            self._state = False
+            self._attr_is_on = False
             self.async_write_ha_state()
