@@ -80,10 +80,12 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
         try:
             await async_migrate_entries(hass, entry.entry_id, update_unique_id)
             _LOGGER.warning(
-                "Migrating PVPC sensor from old tariff '%s' to new '%s'. "
-                "Configure the integration to set your contracted power, "
-                "and select prices for Ceuta/Melilla, "
-                "if that is your case",
+                (
+                    "Migrating PVPC sensor from old tariff '%s' to new '%s'. "
+                    "Configure the integration to set your contracted power, "
+                    "and select prices for Ceuta/Melilla, "
+                    "if that is your case"
+                ),
                 entry.data[ATTR_TARIFF],
                 _DEFAULT_TARIFF,
             )
@@ -95,8 +97,10 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
                 if reg_entry.config_entry_id == entry.entry_id:
                     ent_reg.async_remove(entity_id)
                     _LOGGER.warning(
-                        "Old PVPC Sensor %s is removed "
-                        "(another one already exists, using the same tariff)",
+                        (
+                            "Old PVPC Sensor %s is removed "
+                            "(another one already exists, using the same tariff)"
+                        ),
                         entity_id,
                     )
                     break
