@@ -3,7 +3,7 @@ from __future__ import annotations
 
 from collections.abc import Callable, Iterable
 import contextlib
-from dataclasses import dataclass
+from dataclasses import dataclass, replace as dataclass_replace
 from datetime import timedelta
 import logging
 from typing import TYPE_CHECKING
@@ -37,9 +37,11 @@ from .db_schema import (
 )
 from .models import process_timestamp
 from .statistics import (
+    correct_db_schema as statistics_correct_db_schema,
     delete_statistics_duplicates,
     delete_statistics_meta_duplicates,
     get_start_time,
+    validate_db_schema as statistics_validate_db_schema,
 )
 from .util import session_scope
 
@@ -83,6 +85,8 @@ class SchemaValidationStatus:
     """Store schema validation status."""
 
     current_version: int
+    statistics_schema_errors: set[str]
+    valid: bool
 
 
 def _schema_is_current(current_version: int) -> bool:
@@ -90,13 +94,8 @@ def _schema_is_current(current_version: int) -> bool:
     return current_version == SCHEMA_VERSION
 
 
-def schema_is_valid(schema_status: SchemaValidationStatus) -> bool:
-    """Check if the schema is valid."""
-    return _schema_is_current(schema_status.current_version)
-
-
 def validate_db_schema(
-    hass: HomeAssistant, session_maker: Callable[[], Session]
+    hass: HomeAssistant, engine: Engine, session_maker: Callable[[], Session]
 ) -> SchemaValidationStatus | None:
     """Check if the schema is valid.
 
@@ -104,11 +103,20 @@ def validate_db_schema(
     errors caused by manual migration between database engines, for example importing an
     SQLite database to MariaDB.
     """
+    schema_errors: set[str] = set()
+
     current_version = get_schema_version(session_maker)
     if current_version is None:
         return None
 
-    return SchemaValidationStatus(current_version)
+    if is_current := _schema_is_current(current_version):
+        # We can only check for further errors if the schema is current, because
+        # columns may otherwise not exist etc.
+        schema_errors |= statistics_validate_db_schema(hass, engine, session_maker)
+
+    valid = is_current and not schema_errors
+
+    return SchemaValidationStatus(current_version, schema_errors, valid)
 
 
 def live_migration(schema_status: SchemaValidationStatus) -> bool:
@@ -125,10 +133,18 @@ def migrate_schema(
 ) -> None:
     """Check if the schema needs to be upgraded."""
     current_version = schema_status.current_version
-    _LOGGER.warning("Database is about to upgrade. Schema version: %s", current_version)
+    if current_version != SCHEMA_VERSION:
+        _LOGGER.warning(
+            "Database is about to upgrade from schema version: %s to: %s",
+            current_version,
+            SCHEMA_VERSION,
+        )
     db_ready = False
     for version in range(current_version, SCHEMA_VERSION):
-        if live_migration(SchemaValidationStatus(version)) and not db_ready:
+        if (
+            live_migration(dataclass_replace(schema_status, current_version=version))
+            and not db_ready
+        ):
             db_ready = True
             instance.migration_is_live = True
             hass.add_job(instance.async_set_db_ready)
@@ -140,6 +156,13 @@ def migrate_schema(
 
         _LOGGER.info("Upgrade to version %s done", new_version)
 
+    if schema_errors := schema_status.statistics_schema_errors:
+        _LOGGER.warning(
+            "Database is about to correct DB schema errors: %s",
+            ", ".join(sorted(schema_errors)),
+        )
+        statistics_correct_db_schema(instance, engine, session_maker, schema_errors)
+
 
 def _create_index(
     session_maker: Callable[[], Session], table_name: str, index_name: str
@@ -159,9 +182,11 @@ def _create_index(
     index = index_list[0]
     _LOGGER.debug("Creating %s index", index_name)
     _LOGGER.warning(
-        "Adding index `%s` to database. Note: this can take several "
-        "minutes on large databases and slow computers. Please "
-        "be patient!",
+        (
+            "Adding index `%s` to database. Note: this can take several "
+            "minutes on large databases and slow computers. Please "
+            "be patient!"
+        ),
         index_name,
     )
     with session_scope(session=session_maker()) as session:
@@ -248,9 +273,11 @@ def _drop_index(
             return
 
         _LOGGER.warning(
-            "Failed to drop index %s from table %s. Schema "
-            "Migration will continue; this is not a "
-            "critical operation",
+            (
+                "Failed to drop index %s from table %s. Schema "
+                "Migration will continue; this is not a "
+                "critical operation"
+            ),
             index_name,
             table_name,
         )
@@ -261,9 +288,11 @@ def _add_columns(
 ) -> None:
     """Add columns to a table."""
     _LOGGER.warning(
-        "Adding columns %s to table %s. Note: this can take several "
-        "minutes on large databases and slow computers. Please "
-        "be patient!",
+        (
+            "Adding columns %s to table %s. Note: this can take several "
+            "minutes on large databases and slow computers. Please "
+            "be patient!"
+        ),
         ", ".join(column.split(" ")[0] for column in columns_def),
         table_name,
     )
@@ -315,18 +344,22 @@ def _modify_columns(
     """Modify columns in a table."""
     if engine.dialect.name == SupportedDialect.SQLITE:
         _LOGGER.debug(
-            "Skipping to modify columns %s in table %s; "
-            "Modifying column length in SQLite is unnecessary, "
-            "it does not impose any length restrictions",
+            (
+                "Skipping to modify columns %s in table %s; "
+                "Modifying column length in SQLite is unnecessary, "
+                "it does not impose any length restrictions"
+            ),
             ", ".join(column.split(" ")[0] for column in columns_def),
             table_name,
         )
         return
 
     _LOGGER.warning(
-        "Modifying columns %s in table %s. Note: this can take several "
-        "minutes on large databases and slow computers. Please "
-        "be patient!",
+        (
+            "Modifying columns %s in table %s. Note: this can take several "
+            "minutes on large databases and slow computers. Please "
+            "be patient!"
+        ),
         ", ".join(column.split(" ")[0] for column in columns_def),
         table_name,
     )
@@ -613,9 +646,11 @@ def _apply_update(  # noqa: C901
         if engine.dialect.name == SupportedDialect.MYSQL:
             for table in ("events", "states", "statistics_meta"):
                 _LOGGER.warning(
-                    "Updating character set and collation of table %s to utf8mb4. "
-                    "Note: this can take several minutes on large databases and slow "
-                    "computers. Please be patient!",
+                    (
+                        "Updating character set and collation of table %s to utf8mb4."
+                        " Note: this can take several minutes on large databases and"
+                        " slow computers. Please be patient!"
+                    ),
                     table,
                 )
                 with contextlib.suppress(SQLAlchemyError):
@@ -625,8 +660,8 @@ def _apply_update(  # noqa: C901
                             # Using LOCK=EXCLUSIVE to prevent the database from corrupting
                             # https://github.com/home-assistant/core/issues/56104
                             text(
-                                f"ALTER TABLE {table} CONVERT TO "
-                                "CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci, LOCK=EXCLUSIVE"
+                                f"ALTER TABLE {table} CONVERT TO CHARACTER SET utf8mb4"
+                                " COLLATE utf8mb4_unicode_ci, LOCK=EXCLUSIVE"
                             )
                         )
     elif new_version == 22:
