@@ -1,11 +1,11 @@
 """An abstract class common to all Switchbot entities."""
 from __future__ import annotations
 
-from abc import abstractmethod
 from collections.abc import Mapping
+import logging
 from typing import Any
 
-from switchbot import SwitchbotDevice
+from switchbot import Switchbot, SwitchbotDevice
 
 from homeassistant.components.bluetooth.passive_update_coordinator import (
     PassiveBluetoothCoordinatorEntity,
@@ -13,17 +13,20 @@ from homeassistant.components.bluetooth.passive_update_coordinator import (
 from homeassistant.const import ATTR_CONNECTIONS
 from homeassistant.core import callback
 from homeassistant.helpers import device_registry as dr
-from homeassistant.helpers.entity import DeviceInfo
+from homeassistant.helpers.entity import DeviceInfo, ToggleEntity
 
 from .const import MANUFACTURER
 from .coordinator import SwitchbotDataUpdateCoordinator
 
+_LOGGER = logging.getLogger(__name__)
+
 
 class SwitchbotEntity(PassiveBluetoothCoordinatorEntity):
     """Generic entity encapsulating common features of Switchbot device."""
 
     coordinator: SwitchbotDataUpdateCoordinator
     _device: SwitchbotDevice
+    _attr_has_entity_name = True
 
     def __init__(self, coordinator: SwitchbotDataUpdateCoordinator) -> None:
         """Initialize the entity."""
@@ -32,7 +35,6 @@ class SwitchbotEntity(PassiveBluetoothCoordinatorEntity):
         self._last_run_success: bool | None = None
         self._address = coordinator.ble_device.address
         self._attr_unique_id = coordinator.base_unique_id
-        self._attr_name = coordinator.device_name
         self._attr_device_info = DeviceInfo(
             connections={(dr.CONNECTION_BLUETOOTH, self._address)},
             manufacturer=MANUFACTURER,
@@ -51,20 +53,16 @@ class SwitchbotEntity(PassiveBluetoothCoordinatorEntity):
         )
 
     @property
-    def data(self) -> dict[str, Any]:
-        """Return coordinator data for this entity."""
-        return self.coordinator.data
+    def parsed_data(self) -> dict[str, Any]:
+        """Return parsed device data for this entity."""
+        return self.coordinator.device.parsed_data
 
     @property
     def extra_state_attributes(self) -> Mapping[Any, Any]:
         """Return the state attributes."""
         return {"last_run_success": self._last_run_success}
 
-
-class SwitchbotSubscribeEntity(SwitchbotEntity):
-    """Base class for Switchbot entities that use subscribe."""
-
-    @abstractmethod
+    @callback
     def _async_update_attrs(self) -> None:
         """Update the entity attributes."""
 
@@ -85,3 +83,27 @@ class SwitchbotSubscribeEntity(SwitchbotEntity):
         Only used by the generic entity update service.
         """
         await self._device.update()
+
+
+class SwitchbotSwitchedEntity(SwitchbotEntity, ToggleEntity):
+    """Base class for Switchbot entities that can be turned on and off."""
+
+    _device: Switchbot
+
+    async def async_turn_on(self, **kwargs: Any) -> None:
+        """Turn device on."""
+        _LOGGER.debug("Turn Switchbot device on %s", self._address)
+
+        self._last_run_success = bool(await self._device.turn_on())
+        if self._last_run_success:
+            self._attr_is_on = True
+        self.async_write_ha_state()
+
+    async def async_turn_off(self, **kwargs: Any) -> None:
+        """Turn device off."""
+        _LOGGER.debug("Turn Switchbot device off %s", self._address)
+
+        self._last_run_success = bool(await self._device.turn_off())
+        if self._last_run_success:
+            self._attr_is_on = False
+        self.async_write_ha_state()
