@@ -11,11 +11,11 @@ from homeassistant.components.sensor import (
 )
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
-    ENERGY_KILO_WATT_HOUR,
     PERCENTAGE,
-    POWER_WATT,
-    TEMP_CELSIUS,
-    VOLUME_CUBIC_METERS,
+    UnitOfEnergy,
+    UnitOfPower,
+    UnitOfTemperature,
+    UnitOfVolume,
 )
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -132,7 +132,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         name="Temperature",
         section="thermostat",
         measurement="current_display_temperature",
-        native_unit_of_measurement=TEMP_CELSIUS,
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
@@ -164,7 +164,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         section="gas_usage",
         measurement="day_average",
         device_class=SensorDeviceClass.GAS,
-        native_unit_of_measurement=VOLUME_CUBIC_METERS,
+        native_unit_of_measurement=UnitOfVolume.CUBIC_METERS,
         entity_registry_enabled_default=False,
         cls=ToonGasMeterDeviceSensor,
     ),
@@ -174,7 +174,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         section="gas_usage",
         measurement="day_usage",
         device_class=SensorDeviceClass.GAS,
-        native_unit_of_measurement=VOLUME_CUBIC_METERS,
+        native_unit_of_measurement=UnitOfVolume.CUBIC_METERS,
         cls=ToonGasMeterDeviceSensor,
     ),
     ToonSensorEntityDescription(
@@ -193,7 +193,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         name="Gas Meter",
         section="gas_usage",
         measurement="meter",
-        native_unit_of_measurement=VOLUME_CUBIC_METERS,
+        native_unit_of_measurement=UnitOfVolume.CUBIC_METERS,
         state_class=SensorStateClass.TOTAL_INCREASING,
         device_class=SensorDeviceClass.GAS,
         cls=ToonGasMeterDeviceSensor,
@@ -212,7 +212,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         name="Average Power Usage",
         section="power_usage",
         measurement="average",
-        native_unit_of_measurement=POWER_WATT,
+        native_unit_of_measurement=UnitOfPower.WATT,
         device_class=SensorDeviceClass.POWER,
         entity_registry_enabled_default=False,
         cls=ToonElectricityMeterDeviceSensor,
@@ -222,7 +222,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         name="Average Daily Energy Usage",
         section="power_usage",
         measurement="day_average",
-        native_unit_of_measurement=ENERGY_KILO_WATT_HOUR,
+        native_unit_of_measurement=UnitOfEnergy.KILO_WATT_HOUR,
         device_class=SensorDeviceClass.ENERGY,
         entity_registry_enabled_default=False,
         cls=ToonElectricityMeterDeviceSensor,
@@ -243,7 +243,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         name="Energy Usage Today",
         section="power_usage",
         measurement="day_usage",
-        native_unit_of_measurement=ENERGY_KILO_WATT_HOUR,
+        native_unit_of_measurement=UnitOfEnergy.KILO_WATT_HOUR,
         device_class=SensorDeviceClass.ENERGY,
         cls=ToonElectricityMeterDeviceSensor,
     ),
@@ -252,7 +252,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         name="Electricity Meter Feed IN Tariff 1",
         section="power_usage",
         measurement="meter_high",
-        native_unit_of_measurement=ENERGY_KILO_WATT_HOUR,
+        native_unit_of_measurement=UnitOfEnergy.KILO_WATT_HOUR,
         device_class=SensorDeviceClass.ENERGY,
         state_class=SensorStateClass.TOTAL_INCREASING,
         cls=ToonElectricityMeterDeviceSensor,
@@ -262,7 +262,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         name="Electricity Meter Feed IN Tariff 2",
         section="power_usage",
         measurement="meter_low",
-        native_unit_of_measurement=ENERGY_KILO_WATT_HOUR,
+        native_unit_of_measurement=UnitOfEnergy.KILO_WATT_HOUR,
         device_class=SensorDeviceClass.ENERGY,
         state_class=SensorStateClass.TOTAL_INCREASING,
         cls=ToonElectricityMeterDeviceSensor,
@@ -272,7 +272,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         name="Current Power Usage",
         section="power_usage",
         measurement="current",
-        native_unit_of_measurement=POWER_WATT,
+        native_unit_of_measurement=UnitOfPower.WATT,
         device_class=SensorDeviceClass.POWER,
         state_class=SensorStateClass.MEASUREMENT,
         cls=ToonElectricityMeterDeviceSensor,
@@ -282,7 +282,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         name="Electricity Meter Feed OUT Tariff 1",
         section="power_usage",
         measurement="meter_produced_high",
-        native_unit_of_measurement=ENERGY_KILO_WATT_HOUR,
+        native_unit_of_measurement=UnitOfEnergy.KILO_WATT_HOUR,
         device_class=SensorDeviceClass.ENERGY,
         state_class=SensorStateClass.TOTAL_INCREASING,
         cls=ToonElectricityMeterDeviceSensor,
@@ -292,7 +292,7 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         name="Electricity Meter Feed OUT Tariff 2",
         section="power_usage",
         measurement="meter_produced_low",
-        native_unit_of_measurement=ENERGY_KILO_WATT_HOUR,
+        native_unit_of_measurement=UnitOfEnergy.KILO_WATT_HOUR,
         device_class=SensorDeviceClass.ENERGY,
         state_class=SensorStateClass.TOTAL_INCREASING,
         cls=ToonElectricityMeterDeviceSensor,
@@ -312,31 +312,34 @@ SENSOR_ENTITIES: tuple[ToonSensorEntityDescription, ...] = (
         name="Average Daily Water Usage",
         section="water_usage",
         measurement="day_average",
-        native_unit_of_measurement=VOLUME_CUBIC_METERS,
+        native_unit_of_measurement=UnitOfVolume.CUBIC_METERS,
         icon="mdi:water",
         entity_registry_enabled_default=False,
         cls=ToonWaterMeterDeviceSensor,
+        device_class=SensorDeviceClass.WATER,
     ),
     ToonSensorEntityDescription(
         key="water_daily_usage",
         name="Water Usage Today",
         section="water_usage",
         measurement="day_usage",
-        native_unit_of_measurement=VOLUME_CUBIC_METERS,
+        native_unit_of_measurement=UnitOfVolume.CUBIC_METERS,
         icon="mdi:water",
         entity_registry_enabled_default=False,
         cls=ToonWaterMeterDeviceSensor,
+        device_class=SensorDeviceClass.WATER,
     ),
     ToonSensorEntityDescription(
         key="water_meter_reading",
         name="Water Meter",
         section="water_usage",
         measurement="meter",
-        native_unit_of_measurement=VOLUME_CUBIC_METERS,
+        native_unit_of_measurement=UnitOfVolume.CUBIC_METERS,
         icon="mdi:water",
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.TOTAL_INCREASING,
         cls=ToonWaterMeterDeviceSensor,
+        device_class=SensorDeviceClass.WATER,
     ),
     ToonSensorEntityDescription(
         key="water_value",
@@ -369,7 +372,7 @@ SENSOR_ENTITIES_SOLAR: tuple[ToonSensorEntityDescription, ...] = (
         name="Current Solar Power Production",
         section="power_usage",
         measurement="current_solar",
-        native_unit_of_measurement=POWER_WATT,
+        native_unit_of_measurement=UnitOfPower.WATT,
         device_class=SensorDeviceClass.POWER,
         state_class=SensorStateClass.MEASUREMENT,
         cls=ToonSolarDeviceSensor,
@@ -379,7 +382,7 @@ SENSOR_ENTITIES_SOLAR: tuple[ToonSensorEntityDescription, ...] = (
         name="Max Solar Power Production Today",
         section="power_usage",
         measurement="day_max_solar",
-        native_unit_of_measurement=POWER_WATT,
+        native_unit_of_measurement=UnitOfPower.WATT,
         device_class=SensorDeviceClass.POWER,
         cls=ToonSolarDeviceSensor,
     ),
@@ -388,7 +391,7 @@ SENSOR_ENTITIES_SOLAR: tuple[ToonSensorEntityDescription, ...] = (
         name="Solar Power Production to Grid",
         section="power_usage",
         measurement="current_produced",
-        native_unit_of_measurement=POWER_WATT,
+        native_unit_of_measurement=UnitOfPower.WATT,
         device_class=SensorDeviceClass.POWER,
         state_class=SensorStateClass.MEASUREMENT,
         cls=ToonSolarDeviceSensor,
@@ -398,7 +401,7 @@ SENSOR_ENTITIES_SOLAR: tuple[ToonSensorEntityDescription, ...] = (
         name="Solar Energy Produced Today",
         section="power_usage",
         measurement="day_produced_solar",
-        native_unit_of_measurement=ENERGY_KILO_WATT_HOUR,
+        native_unit_of_measurement=UnitOfEnergy.KILO_WATT_HOUR,
         device_class=SensorDeviceClass.ENERGY,
         state_class=SensorStateClass.TOTAL_INCREASING,
         cls=ToonSolarDeviceSensor,
@@ -408,7 +411,7 @@ SENSOR_ENTITIES_SOLAR: tuple[ToonSensorEntityDescription, ...] = (
         name="Energy Produced To Grid Today",
         section="power_usage",
         measurement="day_to_grid_usage",
-        native_unit_of_measurement=ENERGY_KILO_WATT_HOUR,
+        native_unit_of_measurement=UnitOfEnergy.KILO_WATT_HOUR,
         device_class=SensorDeviceClass.ENERGY,
         entity_registry_enabled_default=False,
         cls=ToonSolarDeviceSensor,
@@ -418,7 +421,7 @@ SENSOR_ENTITIES_SOLAR: tuple[ToonSensorEntityDescription, ...] = (
         name="Energy Usage From Grid Today",
         section="power_usage",
         measurement="day_from_grid_usage",
-        native_unit_of_measurement=ENERGY_KILO_WATT_HOUR,
+        native_unit_of_measurement=UnitOfEnergy.KILO_WATT_HOUR,
         device_class=SensorDeviceClass.ENERGY,
         entity_registry_enabled_default=False,
         cls=ToonSolarDeviceSensor,
@@ -428,7 +431,7 @@ SENSOR_ENTITIES_SOLAR: tuple[ToonSensorEntityDescription, ...] = (
         name="Average Solar Power Production to Grid",
         section="power_usage",
         measurement="average_produced",
-        native_unit_of_measurement=POWER_WATT,
+        native_unit_of_measurement=UnitOfPower.WATT,
         device_class=SensorDeviceClass.POWER,
         entity_registry_enabled_default=False,
         cls=ToonSolarDeviceSensor,
