@@ -9,14 +9,20 @@ from __future__ import annotations
 import asyncio
 from collections.abc import Callable, Coroutine
 from dataclasses import dataclass
-from typing import Any, Generic, TypeVar
+from typing import Any, Generic, TypeVar, Union
 
 import aiounifi
-from aiounifi.interfaces.api_handlers import CallbackType, ItemEvent, UnsubscribeType
+from aiounifi.interfaces.api_handlers import (
+    APIHandler,
+    CallbackType,
+    ItemEvent,
+    UnsubscribeType,
+)
 from aiounifi.interfaces.clients import Clients
 from aiounifi.interfaces.dpi_restriction_groups import DPIRestrictionGroups
 from aiounifi.interfaces.outlets import Outlets
 from aiounifi.interfaces.ports import Ports
+from aiounifi.models.api import APIItem
 from aiounifi.models.client import Client, ClientBlockRequest
 from aiounifi.models.device import (
     DeviceSetOutletRelayRequest,
@@ -51,8 +57,8 @@ from .controller import UniFiController
 CLIENT_BLOCKED = (EventKey.WIRED_CLIENT_BLOCKED, EventKey.WIRELESS_CLIENT_BLOCKED)
 CLIENT_UNBLOCKED = (EventKey.WIRED_CLIENT_UNBLOCKED, EventKey.WIRELESS_CLIENT_UNBLOCKED)
 
-Data = TypeVar("Data")
-Handler = TypeVar("Handler")
+_DataT = TypeVar("_DataT", bound=Union[APIItem, Outlet, Port])
+_HandlerT = TypeVar("_HandlerT", bound=Union[APIHandler, Outlets, Ports])
 
 Subscription = Callable[[CallbackType, ItemEvent], UnsubscribeType]
 
@@ -157,25 +163,27 @@ async def async_poe_port_control_fn(
 
 
 @dataclass
-class UnifiEntityLoader(Generic[Handler, Data]):
+class UnifiEntityLoader(Generic[_HandlerT, _DataT]):
     """Validate and load entities from different UniFi handlers."""
 
     allowed_fn: Callable[[UniFiController, str], bool]
-    api_handler_fn: Callable[[aiounifi.Controller], Handler]
+    api_handler_fn: Callable[[aiounifi.Controller], _HandlerT]
     available_fn: Callable[[UniFiController, str], bool]
     control_fn: Callable[[aiounifi.Controller, str, bool], Coroutine[Any, Any, None]]
     device_info_fn: Callable[[aiounifi.Controller, str], DeviceInfo]
     event_is_on: tuple[EventKey, ...] | None
     event_to_subscribe: tuple[EventKey, ...] | None
-    is_on_fn: Callable[[aiounifi.Controller, Data], bool]
-    name_fn: Callable[[Data], str | None]
-    object_fn: Callable[[aiounifi.Controller, str], Data]
+    is_on_fn: Callable[[aiounifi.Controller, _DataT], bool]
+    name_fn: Callable[[_DataT], str | None]
+    object_fn: Callable[[aiounifi.Controller, str], _DataT]
     supported_fn: Callable[[aiounifi.Controller, str], bool | None]
     unique_id_fn: Callable[[str], str]
 
 
 @dataclass
-class UnifiEntityDescription(SwitchEntityDescription, UnifiEntityLoader[Handler, Data]):
+class UnifiEntityDescription(
+    SwitchEntityDescription, UnifiEntityLoader[_HandlerT, _DataT]
+):
     """Class describing UniFi switch entity."""
 
     custom_subscribe: Callable[[aiounifi.Controller], Subscription] | None = None
@@ -307,17 +315,17 @@ async def async_setup_entry(
         async_load_entities(description)
 
 
-class UnifiSwitchEntity(SwitchEntity):
+class UnifiSwitchEntity(SwitchEntity, Generic[_HandlerT, _DataT]):
     """Base representation of a UniFi switch."""
 
-    entity_description: UnifiEntityDescription
+    entity_description: UnifiEntityDescription[_HandlerT, _DataT]
     _attr_should_poll = False
 
     def __init__(
         self,
         obj_id: str,
         controller: UniFiController,
-        description: UnifiEntityDescription,
+        description: UnifiEntityDescription[_HandlerT, _DataT],
     ) -> None:
         """Set up UniFi switch entity."""
         self._obj_id = obj_id
@@ -353,6 +361,7 @@ class UnifiSwitchEntity(SwitchEntity):
         self.async_on_remove(
             handler.subscribe(
                 self.async_signalling_callback,
+                id_filter=self._obj_id,
             )
         )
         self.async_on_remove(
@@ -402,11 +411,20 @@ class UnifiSwitchEntity(SwitchEntity):
             self.hass.async_create_task(self.remove_item({self._obj_id}))
             return
 
+        update_state = False
+
         if not description.only_event_for_state_change:
             obj = description.object_fn(self.controller.api, self._obj_id)
-            self._attr_is_on = description.is_on_fn(self.controller.api, obj)
-        self._attr_available = description.available_fn(self.controller, self._obj_id)
-        self.async_write_ha_state()
+            if (is_on := description.is_on_fn(self.controller.api, obj)) != self.is_on:
+                self._attr_is_on = is_on
+                update_state = True
+        if (
+            available := description.available_fn(self.controller, self._obj_id)
+        ) != self.available:
+            self._attr_available = available
+            update_state = True
+        if update_state:
+            self.async_write_ha_state()
 
     @callback
     def async_signal_reachable_callback(self) -> None:
